@@ -247,7 +247,7 @@ def delhubgroup(groupName):
 	groupCleanup(db, groupName)
 
 
-def addhubgroup(groupName, description='', type=0):
+def addhubgroup(groupName, description='', gidNumber=0, type=0):
 
 	# grab config options
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
@@ -255,8 +255,11 @@ def addhubgroup(groupName, description='', type=0):
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
-        gidNumber = _insert_jos_xgroups(db, groupName, description, type)
-        add_ldap_group(groupName, description, gidNumber)
+	if not groupExists(groupName):
+		gidNumber = _insert_jos_xgroups(db, groupName, description, gidNumber, type)
+		add_ldap_group(groupName, description, gidNumber)
+	else:
+		return -1
 
 	return gidNumber	
 
@@ -269,7 +272,7 @@ def addhubgroupdbonly(groupName, description='', gid=0, type=0):
 	dbName = hubzero.config.webconfig.getWebConfigDBName()
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
-        gidNumber = _insert_jos_xgroups(db, groupName, description, type, gid)
+	gidNumber = _insert_jos_xgroups(db, groupName, description, type, gid)
 	return gidNumber	
 
 
